Documentation
¶
Index ¶
- type Spamoor
- func (s *Spamoor) GetClient(client *execution.Client) *spamoor.Client
- func (s *Spamoor) GetClientPool() *spamoor.ClientPool
- func (s *Spamoor) GetReadyClient() *spamoor.Client
- func (s *Spamoor) GetTxPool() *spamoor.TxPool
- func (s *Spamoor) GetWalletByAddress(ctx context.Context, address common.Address) (*spamoor.Wallet, error)
- func (s *Spamoor) GetWalletByPrivkey(ctx context.Context, privkey *ecdsa.PrivateKey) (*spamoor.Wallet, error)
- func (s *Spamoor) GetWalletPoolByPrivkey(ctx context.Context, logger logrus.FieldLogger, privkey *ecdsa.PrivateKey, ...) (*spamoor.WalletPool, error)
- func (s *Spamoor) NewWalletPoolByPrivkey(ctx context.Context, logger logrus.FieldLogger, privkey *ecdsa.PrivateKey) (*spamoor.WalletPool, error)
- type WalletPoolConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Spamoor ¶
type Spamoor struct {
// contains filtered or unexported fields
}
func NewSpamoor ¶
func (*Spamoor) GetClientPool ¶
func (s *Spamoor) GetClientPool() *spamoor.ClientPool
func (*Spamoor) GetReadyClient ¶
func (*Spamoor) GetWalletByAddress ¶
func (*Spamoor) GetWalletByPrivkey ¶
func (*Spamoor) GetWalletPoolByPrivkey ¶
func (s *Spamoor) GetWalletPoolByPrivkey(ctx context.Context, logger logrus.FieldLogger, privkey *ecdsa.PrivateKey, config *WalletPoolConfig) (*spamoor.WalletPool, error)
GetWalletPoolByPrivkey creates a wallet pool with child wallets derived from the given private key. This method prepares the wallets immediately after creation.
func (*Spamoor) NewWalletPoolByPrivkey ¶
func (s *Spamoor) NewWalletPoolByPrivkey(ctx context.Context, logger logrus.FieldLogger, privkey *ecdsa.PrivateKey) (*spamoor.WalletPool, error)
NewWalletPoolByPrivkey creates a wallet pool without preparation. Use this when the wallet count and config will be set by a scenario. Call walletPool.PrepareWallets() after configuration is complete.
Click to show internal directories.
Click to hide internal directories.